#version 330

uniform vec4 ambient;
uniform vec4 diffuse;
uniform vec4 specular;
uniform float spotCosCutoff[10];
uniform vec4 lightPos[10];

in vec3 spot[10];
in vec3 normal, vertex;
in vec4 color;

out vec4 fragColor;

void main(void) 
{		
	vec4 outColor;
	vec3 N = normalize(normal);
	vec3 E = normalize(-vertex);
	float att;
	vec4 diff = vec4(0,0,0,1);
	vec4 spec = vec4(0,0,0,1);

	
	vec3 L = normalize(vec3(lightPos[2]) - vertex);
	float NdotL = max(0.0, dot(N,L));
	vec3 R = normalize(-reflect(L,N));
	if(NdotL > 0.0) {
		diff += diffuse * NdotL * vec4(0.1,0.1,0.1,1);
		diff = clamp(diff, 0.0, 1.0);
	}

	for(int i=3;i<10;i++) {
		vec3 L = normalize(vec3(lightPos[i]) - vertex);
		float NdotL = max(0.0, dot(N,L));
		vec3 R = normalize(-reflect(L,N));

		if(NdotL > 0.0) {
			float spotEffect = dot(normalize(-L), normalize(spot[i]));
		
			if (spotEffect > spotCosCutoff[i]) {
				spotEffect = pow(spotEffect, 8.0);
				att = spotEffect/0.7;

				diff += att * diffuse * NdotL;
				diff = clamp(diff, 0.0, 1.0);
			
				spec += att * specular * pow(max(dot(R,E),0.0),120.0);
				spec = clamp(spec, 0.0, 1.0);
			}
		}
	}
	outColor = clamp(ambient + diff, 0.0, 1.0) * color;
	outColor.rgb += spec.rgb;
	fragColor = outColor;
}

